@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     30/03/2002
-// RCS-ID:      $Id: event.h,v 1.9 2004/12/21 21:12:45 mbarbon Exp $
-// Copyright:   (c) 2002-2004 Mattia Barbon
+// RCS-ID:      $Id: event.h,v 1.11 2006/11/06 23:50:42 mbarbon Exp $
+// Copyright:   (c) 2002-2004, 2006 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -14,7 +14,7 @@
 
 #include "cpp/v_cback.h"
 
-class wxPlEvent:public wxEvent
+class wxPlEvent : public wxEvent
 {
     WXPLI_DECLARE_DYNAMIC_CLASS( wxPlEvent );
     WXPLI_DECLARE_V_CBACK();
@@ -26,6 +26,11 @@ public:
         m_callback.SetSelf( wxPli_make_object( this, package ), true );
     }
 
+    virtual ~wxPlEvent()
+    {
+        m_callback.DeleteSelf( false );
+    }
+
     virtual wxEvent* Clone() const;
 };
 
@@ -40,7 +45,6 @@ wxEvent* wxPlEvent::Clone() const
             ( aTHX_ &self->m_callback, G_SCALAR, NULL );
         wxPlEvent* clone =
             (wxPlEvent*)wxPli_sv_2_object( aTHX_ ret, "Wx::PlEvent" );
-        SvREFCNT_dec( ret );
         
         return clone;
     }
@@ -50,7 +54,7 @@ wxEvent* wxPlEvent::Clone() const
 
 WXPLI_IMPLEMENT_DYNAMIC_CLASS( wxPlEvent, wxEvent );
 
-class wxPlCommandEvent:public wxCommandEvent
+class wxPlCommandEvent : public wxCommandEvent
 {
     WXPLI_DECLARE_DYNAMIC_CLASS( wxPlCommandEvent );
     WXPLI_DECLARE_V_CBACK();
@@ -62,6 +66,11 @@ public:
         m_callback.SetSelf( wxPli_make_object( this, package ), true );
     }
 
+    virtual ~wxPlCommandEvent()
+    {
+        m_callback.DeleteSelf( false );
+    }
+
     virtual wxEvent* Clone() const;
 };
 
@@ -76,8 +85,7 @@ wxEvent* wxPlCommandEvent::Clone() const
             ( aTHX_ &self->m_callback, G_SCALAR, NULL );
         wxPlCommandEvent* clone = (wxPlCommandEvent*)
             wxPli_sv_2_object( aTHX_ ret, "Wx::PlCommandEvent" );
-        SvREFCNT_dec( ret );
-        
+
         return clone;
     }
 
@@ -86,7 +94,7 @@ wxEvent* wxPlCommandEvent::Clone() const
 
 WXPLI_IMPLEMENT_DYNAMIC_CLASS( wxPlCommandEvent, wxCommandEvent );
 
-class wxPlThreadEvent:public wxEvent
+class wxPlThreadEvent : public wxEvent
 {
     WXPLI_DECLARE_DYNAMIC_CLASS( wxPlThreadEvent );
 public:
