@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     17/03/2001
-## RCS-ID:      $Id: Html.pm,v 1.10 2006/09/24 15:04:25 mbarbon Exp $
+## RCS-ID:      $Id: Html.pm,v 1.12 2006/11/02 18:35:30 mbarbon Exp $
 ## Copyright:   (c) 2001-2006 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -47,6 +47,9 @@ package Wx::HtmlColourCell;     @ISA = qw(Wx::HtmlCell);
 package Wx::HtmlWidgetCell;     @ISA = qw(Wx::HtmlCell);
 package Wx::HtmlListBox;        @ISA = qw(Wx::VListBox);
 package Wx::PlHtmlListBox;      @ISA = qw(Wx::HtmlListBox);
+package Wx::SimpleHtmlListBox;  @ISA = qw(Wx::HtmlListBox);
+package Wx::HtmlCellEvent;      @ISA = qw(Wx::CommandEvent);
+package Wx::HtmlLinkEvent;      @ISA = qw(Wx::CommandEvent);
 
 1;
 
